
use File::Copy;
use File::Spec;

#
# build_cgi source-script destination-script
#
# Build a CGI script from a source file.
#
# We write the tool_hdr, add a test for system up / down (if the
# cgi script isn't named seed_ctl*), and then add the source file.
#
# Leverage the existing tool_hdr / tool_hdr_py mechanisms.
#

if (@ARGV != 2)
{
    die "Usage: $0 source-script destination-script\n";
}

my($src_script, $dest_script) = @ARGV;

if (! -f $src_script)
{
    die "Source script $src_script does not exist\n";
}

#
# Check if this is a perl or python script, setting $tool_hdr
# to the appropriate tool header generation script.
#
# Also check to see if the script is called seed_ctlsomethign().
# If it is not, set $ctl_test to the function that will generate
# the appropriate code for testing to see if the seed is up or down.
#

my $tool_hdr;
#
# default: do nothing
#
my $ctl_test = sub { return ""; };

#
# Assume a .cgi is really a perl script; bw compatibility.
#

my(undef, $src_path, $src_file) = File::Spec->splitpath($src_script);

if ($src_script =~ /\.(cgi|pl)$/)
{
    $tool_hdr = "$FIG_Config::bin/tool_hdr";
    if ($src_file !~ /^seed_ctl/)
    {
	$ctl_test = \&ctl_test_pl;
    }
}
elsif  ($src_script =~ /\.py$/)
{
    $tool_hdr = "$FIG_Config::bin/tool_hdr_py";
    if ($src_file !~ /^seed_ctl/)
    {
	$ctl_test = \&ctl_test_py;
    }
}
else
{
    die "Source script must end in either .pl or .py.\n";
}

#
# Copy the tool header.
#

my $inp_fh;

open($inp_fh, "$tool_hdr |") or die "Cannot run $tool_hdr: $!\n";

my $dest_fh;

open($dest_fh, ">$dest_script") or die "Cannot open $dest_script for writing: $!\n";


copy($inp_fh, $dest_fh);
close($inp_fh);

#
# Write the ctl_test.
#

my $ctl_code = &$ctl_test();
syswrite($dest_fh, $ctl_code);

#
# Copy the input script.
#

open($inp_fh, "<$src_script") or die "Cannot open $src_script for reading: $!\n";

copy($inp_fh, $dest_fh);
close($inp_fh);

#
# All done. Close the destination, and make executable.
#

close($dest_fh) or die "Close of $dest_script failed: $!\n";

chmod(0775, $dest_script) or die "Chmod of $dest_script failed: $!\n";

#
# write the is-the-seed-up code for perl.
#
sub ctl_test_pl
{
    return <<'EOC';
#
# Perl code to determine if seed is running.
#

use CGI;

if (-f "$FIG_Config::data/Global/why_down")
{
    local $/;
    open my $fh, "<$FIG_Config::data/Global/why_down";
    my $down_msg = <$fh>;
    
    print CGI::header();
    print CGI::head(CGI::title("SEED Server down"));
    print CGI::start_body();
    print CGI::h1("SEED Server down");
    print CGI::p("The seed server is not currently running:");
    print CGI::pre($down_msg);
    print CGI::end_body();
    exit;
}
EOC
}

#
# write the is-the-seed-up code for python.
#
sub ctl_test_py
{
    return <<EOC;
#
# Python code to determine if seed is running.
#
EOC
}

